@@ -7,12 +7,12 @@ use Carp;
 #==================================================================
 # Author    : Djibril Ousmanou
 # Copyright : 2010
-# Update    : 21/09/2010 16:12:39
+# Update    : 23/10/2010 11:18:35
 # AIM       : Create bars graph
 #==================================================================
 
 use vars qw($VERSION);
-$VERSION = '1.00';
+$VERSION = '1.01';
 
 use base qw/ Tk::Derived Tk::Canvas::GradientColor /;
 use Tk::Balloon;
@@ -40,77 +40,20 @@ sub Populate {
     $CompositeWidget->configure( -highlightthickness => 0 );
   }
 
+  my $RefConfigCommon = _get_ConfigSpecs();
+
+  # ConfigSpecs
   $CompositeWidget->ConfigSpecs(
-    -title      => [ 'PASSIVE', 'Title',      'Title',      undef ],
-    -titlecolor => [ 'PASSIVE', 'Titlecolor', 'TitleColor', 'black' ],
-    -titlefont => [ 'PASSIVE', 'Titlefont', 'TitleFont', $CompositeWidget->{RefChart}->{Font}{DefaultTitle} ],
-    -titleposition => [ 'PASSIVE', 'Titleposition', 'TitlePosition', 'center' ],
-    -titleheight =>
-      [ 'PASSIVE', 'Titleheight', 'TitleHeight', $CompositeWidget->{RefChart}->{Title}{Height} ],
 
-    -xlabel      => [ 'PASSIVE', 'Xlabel',      'XLabel',      undef ],
-    -xlabelcolor => [ 'PASSIVE', 'Xlabelcolor', 'XLabelColor', 'black' ],
-    -xlabelfont =>
-      [ 'PASSIVE', 'Xlabelfont', 'XLabelFont', $CompositeWidget->{RefChart}->{Font}{DefaultLabel} ],
-    -xlabelposition => [ 'PASSIVE', 'Xlabelposition', 'XLabelPosition', 'center' ],
-    -xlabelheight   => [
-      'PASSIVE', 'Xlabelheight', 'XLabelHeight', $CompositeWidget->{RefChart}->{Axis}{Xaxis}{xlabelHeight}
-    ],
-    -xlabelskip => [ 'PASSIVE', 'Xlabelskip', 'XLabelSkip', 0 ],
+    # Common options
+    %{$RefConfigCommon},
 
-    -xvaluecolor    => [ 'PASSIVE', 'Xvaluecolor',    'XValueColor',    'black' ],
-    -xvaluevertical => [ 'PASSIVE', 'Xvaluevertical', 'XValueVertical', 0 ],
-    -xvaluespace    => [
-      'PASSIVE',     'Xvaluespace',
-      'XValueSpace', $CompositeWidget->{RefChart}->{Axis}{Xaxis}{ScaleValuesHeight}
-    ],
-    -xvalueview   => [ 'PASSIVE', 'Xvalueview',   'XValueView',   1 ],
-    -yvalueview   => [ 'PASSIVE', 'Yvalueview',   'YValueView',   1 ],
-    -xvaluesregex => [ 'PASSIVE', 'Xvaluesregex', 'XValuesRegex', qr/.+/ ],
-
-    -ylabel      => [ 'PASSIVE', 'Ylabel',      'YLabel',      undef ],
-    -ylabelcolor => [ 'PASSIVE', 'Ylabelcolor', 'YLabelColor', 'black' ],
-    -ylabelfont =>
-      [ 'PASSIVE', 'Ylabelfont', 'YLabelFont', $CompositeWidget->{RefChart}->{Font}{DefaultLabel} ],
-    -ylabelposition => [ 'PASSIVE', 'Ylabelposition', 'YLabelPosition', 'center' ],
-    -ylabelwidth =>
-      [ 'PASSIVE', 'Ylabelwidth', 'YLabelWidth', $CompositeWidget->{RefChart}->{Axis}{Yaxis}{ylabelWidth} ],
-
-    -yvaluecolor => [ 'PASSIVE', 'Yvaluecolor', 'YValueColor', 'black' ],
-
-    -labelscolor => [ 'PASSIVE', 'Labelscolor', 'LabelsColor', undef ],
-    -valuescolor => [ 'PASSIVE', 'Valuescolor', 'ValuesColor', undef ],
-    -textcolor   => [ 'PASSIVE', 'Textcolor',   'TextColor',   undef ],
-    -textfont    => [ 'PASSIVE', 'Textfont',    'TextFont',    undef ],
-
-    -boxaxis      => [ 'PASSIVE', 'Boxaxis',      'BoxAxis',      0 ],
-    -noaxis       => [ 'PASSIVE', 'Noaxis',       'NoAxis',       0 ],
-    -zeroaxisonly => [ 'PASSIVE', 'Zeroaxisonly', 'ZeroAxisOnly', 0 ],
-    -zeroaxis     => [ 'PASSIVE', 'Zeroaxis',     'ZeroAxis',     0 ],
-    -longticks    => [ 'PASSIVE', 'Longticks',    'LongTicks',    0 ],
-
-    -xtickheight =>
-      [ 'PASSIVE', 'Xtickheight', 'XTickHeight', $CompositeWidget->{RefChart}->{Axis}{Xaxis}{TickHeight} ],
-    -xtickview => [ 'PASSIVE', 'Xtickview', 'XTickView', 1 ],
-
-    -yticknumber =>
-      [ 'PASSIVE', 'Yticknumber', 'YTickNumber', $CompositeWidget->{RefChart}->{Axis}{Yaxis}{TickNumber} ],
-    -ytickwidth =>
-      [ 'PASSIVE', 'Ytickwidth', 'YtickWidth', $CompositeWidget->{RefChart}->{Axis}{Yaxis}{TickWidth} ],
-    -ytickview => [ 'PASSIVE', 'Ytickview', 'YTickView', 1 ],
-
-    -alltickview => [ 'PASSIVE', 'Alltickview', 'AllTickView', 1 ],
-
-    -width  => [ 'SELF', 'width',  'Width',  $CompositeWidget->{RefChart}->{Canvas}{Width} ],
-    -height => [ 'SELF', 'height', 'Height', $CompositeWidget->{RefChart}->{Canvas}{Height} ],
-
-    -linewidth  => [ 'PASSIVE', 'Linewidth',  'LineWidth',  1 ],
-    -colordata  => [ 'PASSIVE', 'Colordata',  'ColorData',  $CompositeWidget->{RefChart}->{Legend}{Colors} ],
-    -overwrite  => [ 'PASSIVE', 'Overwrite',  'OverWrite',  0 ],
-    -cumulate   => [ 'PASSIVE', 'Cumulate',   'Cumulate',   0 ],
-    -spacingbar => [ 'PASSIVE', 'Spacingbar', 'SpacingBar', 1 ],
-    -showvalues => [ 'PASSIVE', 'Showvalues', 'ShowValues', 0 ],
-    -outlinebar => [ 'PASSIVE', 'Outlinebar', 'OutlineBar', 'black' ],
+    -overwrite       => [ 'PASSIVE', 'Overwrite',       'OverWrite',       0 ],
+    -cumulate        => [ 'PASSIVE', 'Cumulate',        'Cumulate',        0 ],
+    -spacingbar      => [ 'PASSIVE', 'Spacingbar',      'SpacingBar',      1 ],
+    -showvalues      => [ 'PASSIVE', 'Showvalues',      'ShowValues',      0 ],
+    -barsvaluescolor => [ 'PASSIVE', 'BarsValuescolor', 'BarsValuesColor', 'black' ],
+    -outlinebar      => [ 'PASSIVE', 'Outlinebar',      'OutlineBar',      'black' ],
   );
 
   $CompositeWidget->Delegates( DEFAULT => $CompositeWidget, );
@@ -178,6 +121,12 @@ sub _Balloon {
           $OtherColor = $CompositeWidget->{RefChart}->{Balloon}{ColorData}->[1];
         }
         $CompositeWidget->itemconfigure( $BarTag, -fill => $OtherColor, );
+
+        # Allow value bar to display
+        $CompositeWidget->itemconfigure(
+          $CompositeWidget->{RefChart}->{TAGS}{BarValues},
+          -fill => $CompositeWidget->cget( -barsvaluescolor ),
+        );
       }
     );
 
@@ -189,7 +138,10 @@ sub _Balloon {
         );
 
         # Allow value bar to display
-        $CompositeWidget->itemconfigure( $CompositeWidget->{RefChart}->{TAGS}{BarValues}, -fill => 'black', );
+        $CompositeWidget->itemconfigure(
+          $CompositeWidget->{RefChart}->{TAGS}{BarValues},
+          -fill => $CompositeWidget->cget( -barsvaluescolor ),
+        );
       }
     );
   }
@@ -267,6 +219,11 @@ sub set_legend {
     $CompositeWidget->{RefChart}->{Legend}{titlecolors} = $InfoLegend{-titlecolors};
   }
 
+  # text color
+  if ( defined $InfoLegend{-legendcolor} ) {
+    $CompositeWidget->{RefChart}->{Legend}{legendcolor} = $InfoLegend{-legendcolor};
+  }
+
   # legendmarkerheight
   if ( defined $InfoLegend{-legendmarkerheight} ) {
     $CompositeWidget->{RefChart}->{Legend}{HCube} = $InfoLegend{-legendmarkerheight};
@@ -456,6 +413,7 @@ sub _ViewLegend {
         -text   => $NewLegend,
         -anchor => 'nw',
         -tags   => [ $Tag, $CompositeWidget->{RefChart}->{TAGS}{AllTagsChart}, ],
+        -fill   => $CompositeWidget->{RefChart}->{Legend}{legendcolor},
       );
       if ($legendfont) {
         $CompositeWidget->itemconfigure( $Id, -font => $legendfont, );
@@ -512,6 +470,8 @@ sub _ViewLegend {
 sub _axis {
   my ($CompositeWidget) = @_;
 
+  my $axiscolor = $CompositeWidget->cget( -axiscolor );
+
   # x axis width
   $CompositeWidget->{RefChart}->{Axis}{Xaxis}{Width}
     = $CompositeWidget->{RefChart}->{Canvas}{Width}
@@ -566,6 +526,7 @@ sub _axis {
       $CompositeWidget->{RefChart}->{TAGS}{yAxis}, $CompositeWidget->{RefChart}->{TAGS}{AllAXIS},
       $CompositeWidget->{RefChart}->{TAGS}{AllTagsChart},
     ],
+    -fill => $axiscolor,
   );
 
   #===========================
@@ -585,25 +546,22 @@ sub _axis {
       $CompositeWidget->{RefChart}->{TAGS}{xAxis}, $CompositeWidget->{RefChart}->{TAGS}{AllAXIS},
       $CompositeWidget->{RefChart}->{TAGS}{AllTagsChart},
     ],
+    -fill => $axiscolor,
   );
 
   # POINT (0,0)
+  $CompositeWidget->{RefChart}->{Axis}{Yaxis}{HeightUnit}    # Height unit for value = 1
+    = $CompositeWidget->{RefChart}->{Axis}{Yaxis}{Height}
+    / ( $CompositeWidget->{RefChart}->{Data}{MaxYValue} - $CompositeWidget->{RefChart}->{Data}{MinYValue} );
+
   # min positive value >= 0
   if ( $CompositeWidget->{RefChart}->{Data}{MinYValue} >= 0 ) {
     $CompositeWidget->{RefChart}->{Axis}{Cx0} = $CompositeWidget->{RefChart}->{Axis}{CxMin};
     $CompositeWidget->{RefChart}->{Axis}{Cy0} = $CompositeWidget->{RefChart}->{Axis}{CyMin};
-
-    $CompositeWidget->{RefChart}->{Axis}{Yaxis}{HeightUnit}    # Height unit for value = 1
-      = $CompositeWidget->{RefChart}->{Axis}{Yaxis}{Height}
-      / ( $CompositeWidget->{RefChart}->{Data}{MaxYValue} - 0 );
   }
 
   # min positive value < 0
   else {
-
-    $CompositeWidget->{RefChart}->{Axis}{Yaxis}{HeightUnit}    # Height unit for value = 1
-      = $CompositeWidget->{RefChart}->{Axis}{Yaxis}{Height}
-      / ( $CompositeWidget->{RefChart}->{Data}{MaxYValue} - $CompositeWidget->{RefChart}->{Data}{MinYValue} );
     $CompositeWidget->{RefChart}->{Axis}{Cx0} = $CompositeWidget->{RefChart}->{Axis}{CxMin};
     $CompositeWidget->{RefChart}->{Axis}{Cy0}
       = $CompositeWidget->{RefChart}->{Axis}{CyMin}
@@ -620,6 +578,7 @@ sub _axis {
         $CompositeWidget->{RefChart}->{TAGS}{xAxis0}, $CompositeWidget->{RefChart}->{TAGS}{AllAXIS},
         $CompositeWidget->{RefChart}->{TAGS}{AllTagsChart},
       ],
+      -fill => $axiscolor,
     );
   }
 
@@ -676,19 +635,8 @@ sub _xtick {
     if ( $data =~ m{$RegexXtickselect} ) {
       next unless ( defined $IndiceToSkip{$Indice} );
 
-      # Long tick
-      if ( defined $longticks and $longticks == 1 ) {
-        $Xticky1 = $CompositeWidget->{RefChart}->{Axis}{CyMax};
-        $Xticky2 = $CompositeWidget->{RefChart}->{Axis}{CyMin};
-      }
-
-      $CompositeWidget->createLine(
-        $Xtickx1, $Xticky1, $Xtickx2, $Xticky2,
-        -tags => [
-          $CompositeWidget->{RefChart}->{TAGS}{xTick}, $CompositeWidget->{RefChart}->{TAGS}{AllTick},
-          $CompositeWidget->{RefChart}->{TAGS}{AllTagsChart},
-        ],
-      );
+      # Display xticks short or long
+      $CompositeWidget->_DisplayxTicks( $Xtickx1, $Xticky1, $Xtickx2, $Xticky2 );
 
       if (  defined $CompositeWidget->{RefChart}->{Axis}{Xaxis}{SpaceBetweenTick}
         and defined $CompositeWidget->{RefChart}->{Legend}{WidthOneCaracter} )
@@ -729,6 +677,7 @@ sub _ViewData {
   my $spacingbar         = $CompositeWidget->cget( -spacingbar );
   my $showvalues         = $CompositeWidget->cget( -showvalues );
   my $outlinebar         = $CompositeWidget->cget( -outlinebar );
+  my $barsvaluescolor    = $CompositeWidget->cget( -barsvaluescolor );
 
   # number of value for x axis
   $CompositeWidget->{RefChart}->{Data}{xtickNumber} = $CompositeWidget->{RefChart}->{Data}{NumberXValues};
@@ -797,6 +746,12 @@ sub _ViewData {
         $y = $CompositeWidget->{RefChart}->{Axis}{Cy0}
           - ( $data * $CompositeWidget->{RefChart}->{Axis}{Yaxis}{HeightUnit} );
 
+        #update=
+        if ( $CompositeWidget->{RefChart}->{Data}{MinYValue} > 0 ) {
+          $y += ( $CompositeWidget->{RefChart}->{Data}{MinYValue}
+              * $CompositeWidget->{RefChart}->{Axis}{Yaxis}{HeightUnit} );
+        }
+
         # coordinates x0 and y0 values
         $x0 = $x - $WidthBar;
         $y0 = $CompositeWidget->{RefChart}->{Axis}{Cy0};
@@ -808,6 +763,12 @@ sub _ViewData {
         }
       }
 
+      #update=
+      if ( $CompositeWidget->{RefChart}->{Data}{MaxYValue} < 0 ) {
+        $y0 -= ( $CompositeWidget->{RefChart}->{Data}{MaxYValue}
+            * $CompositeWidget->{RefChart}->{Axis}{Yaxis}{HeightUnit} );
+      }
+
       my $LineColor = $legendmarkercolors->[$IndexColor];
       unless ( defined $LineColor ) {
         $IndexColor = 0;
@@ -823,9 +784,9 @@ sub _ViewData {
         $x0, $y0, $x, $y,
         -fill => $LineColor,
         -tags => [
-          $tag, $tag2,
-          $CompositeWidget->{RefChart}->{TAGS}{AllData},
-          $CompositeWidget->{RefChart}->{TAGS}{AllTagsChart},
+          $tag,                                          $tag2,
+          $CompositeWidget->{RefChart}->{TAGS}{AllData}, $CompositeWidget->{RefChart}->{TAGS}{AllTagsChart},
+          $CompositeWidget->{RefChart}->{TAGS}{AllBars},
         ],
         -width   => $CompositeWidget->cget( -linewidth ),
         -outline => $outlinebar,
@@ -841,6 +802,7 @@ sub _ViewData {
             $CompositeWidget->{RefChart}->{TAGS}{BarValues},
             $CompositeWidget->{RefChart}->{TAGS}{AllTagsChart},
           ],
+          -fill => $barsvaluescolor,
         );
       }
 
@@ -861,6 +823,9 @@ sub plot {
   my $overwrite   = $CompositeWidget->cget( -overwrite );
   my $cumulate    = $CompositeWidget->cget( -cumulate );
   my $yticknumber = $CompositeWidget->cget( -yticknumber );
+  my $yminvalue   = $CompositeWidget->cget( -yminvalue );
+  my $ymaxvalue   = $CompositeWidget->cget( -ymaxvalue );
+  my $interval    = $CompositeWidget->cget( -interval );
 
   if ( defined $option{-substitutionvalue}
     and _isANumber( $option{-substitutionvalue} ) )
@@ -916,6 +881,7 @@ sub plot {
     }
     $i++;
   }
+
   $CompositeWidget->{RefChart}->{Data}{RefXLegend}  = $RefData->[0];
   $CompositeWidget->{RefChart}->{Data}{RefAllData}  = $RefData;
   $CompositeWidget->{RefChart}->{Data}{PlotDefined} = 1;
@@ -925,14 +891,7 @@ sub plot {
     $CompositeWidget->{RefChart}->{Data}{MinYValue} = _MinArray( \@arrayTemp );
   }
 
-  if ( $CompositeWidget->{RefChart}->{Data}{MinYValue} > 0 ) {
-    $CompositeWidget->{RefChart}->{Data}{MinYValue} = 0;
-  }
-  while ( ( $CompositeWidget->{RefChart}->{Data}{MaxYValue} / $yticknumber ) % 5 != 0 ) {
-    $CompositeWidget->{RefChart}->{Data}{MaxYValue}
-      = int( $CompositeWidget->{RefChart}->{Data}{MaxYValue} + 1 );
-  }
-
+  $CompositeWidget->_ManageMinMaxValues( $yticknumber, $cumulate );
   $CompositeWidget->_ChartConstruction;
 
   return 1;
@@ -1074,12 +1033,24 @@ Default : B<0>
 Set this to 1 to display the value of each data point above the point or bar itself. 
 No effort is being made to ensure that there is enough space for the text.
 
-If -overwrite or -cumulate set to 1, some text value could be hide by bars.
+If -overwrite or -cumulate set to 1, the values will not be hide by bars.
 
  -showvalues => 0, # 0 or 1
 
 Default : B<1>
 
+=item Name:	B<BarsValuescolor>
+
+=item Class:	B<BarsValuesColor>
+
+=item Switch:	B<-barsvaluescolor>
+
+Color of each data point above the bar if -showvalues set to 1.
+
+ -barsvaluescolor => 'white',
+
+Default : B<black>
+
 =item Name:	B<Spacingbar>
 
 =item Class:	B<SpacingBar>
@@ -1108,20 +1079,19 @@ Default : B<'black'>
 
 =head1 WIDGET-SPECIFIC OPTIONS like Tk::Chart::Lines
 
-Many options allow you to configure your graph as you want. 
-The default configuration is already OK, but you can change it.
-these are the same option as L<Tk::Chart::Lines> module
+Many options that allow you to configure your graph as you want, but you can skip  
+the default configuration.
 
 =over 4
 
 =item Name:	B<Title>
 
-=item Class:	B<Title>
+=item Class: B<Title>
 
 =item Switch:	B<-title>
 
 Title of your graph.
-  
+
  -title => 'My graph title',
 
 Default : B<undef>
@@ -1140,48 +1110,48 @@ Default : B<center>
 
 =item Name:	B<Titlecolor>
 
-=item Class:	B<TitleColor>
+=item Class: B<TitleColor>
 
 =item Switch:	B<-titlecolor>
 
 Title color of your graph.
-  
+
  -titlecolor => 'red',
 
 Default : B<black>
 
 =item Name:	B<Titlefont>
 
-=item Class:	B<TitleFont>
+=item Class: B<TitleFont>
 
 =item Switch:	B<-titlefont>
 
 Set the font for the title text. See also textfont option. 
-  
+
  -titlefont => 'Times 15 {normal}',
 
 Default : B<{Times} 12 {bold}>
 
 =item Name:	B<Titleheight>
 
-=item Class:	B<TitleHeight>
+=item Class: B<TitleHeight>
 
 =item Switch:	B<-titleheight>
 
 Height for title graph space.
-  
+
  -titleheight => 100,
 
 Default : B<40>
 
 =item Name:	B<Xlabel>
 
-=item Class:	B<XLabel>
+=item Class: B<XLabel>
 
 =item Switch:	B<-xlabel>
 
-The label to be printed just below the x axis.
-  
+The label to be printed just below the x-axis.
+
  -xlabel => 'X label',
 
 Default : B<undef>
@@ -1200,39 +1170,40 @@ Default : B<black>
 
 =item Name:	B<Xlabelfont>
 
-=item Class:	B<XLabelFont>
+=item Class: B<XLabelFont>
 
 =item Switch:	B<-xlabelfont>
 
 Set the font for the x label text. See also textfont option.
-  
+
  -xlabelfont => 'Times 15 {normal}',
 
 Default : B<{Times} 10 {bold}>
 
 =item Name:	B<Xlabelheight>
 
-=item Class:	B<XLabelHeight>
+=item Class: B<XLabelHeight>
 
 =item Switch:	B<-xlabelheight>
 
 Height for x label space.
-  
+
  -xlabelheight => 50,
 
 Default : B<30>
 
 =item Name:	B<Xlabelskip>
 
-=item Class:	B<XLabelSkip>
+=item Class: B<XLabelSkip>
 
 =item Switch:	B<-xlabelskip>
 
-Print every xlabelskip number under the tick on the x axis. If you have a dataset wich contain many points, 
-the tick and x values will be overwrite on the graph. This option can help you to clarify your graph.
+Print every xlabelskip number under the tick on the x-axis. If you have a 
+dataset wich contain many points, the tick and x values will be overwrite 
+on the graph. This option can help you to clarify your graph.
 Eg: 
-  
-  # ['leg1', 'leg2', ...'leg1000', 'leg1001', ... 'leg2000'] => There are 2000 ticks and text values on x axis.
+
+  # ['leg1', 'leg2', ...'leg1000', 'leg1001', ... 'leg2000'] => There are 2000 ticks and text values on x-axis.
   -xlabelskip => 1 => ['leg1', 'leg3', 'leg5', ...]        # => 1000 ticks will be display.
 
 See also -xvaluesregex option.
@@ -1243,12 +1214,12 @@ Default : B<0>
 
 =item Name:	B<Xvaluecolor>
 
-=item Class:	B<XValueColor>
+=item Class: B<XValueColor>
 
 =item Switch:	B<-xvaluecolor>
 
 Set x values colors. See also textcolor option.
- 
+
  -xvaluecolor => 'red',
 
 Default : B<black>
@@ -1260,7 +1231,7 @@ Default : B<black>
 =item Switch:	B<-xvaluespace>
 
 Width for x values space.
- 
+
  -xvaluespace => 50,
 
 Default : B<30>
@@ -1271,7 +1242,7 @@ Default : B<30>
 
 =item Switch:	B<-xvalueview>
 
-View values on x axis.
+View values on x-axis.
  
  -xvalueview => 0, # 0 or 1
 
@@ -1283,14 +1254,13 @@ Default : B<1>
 
 =item Switch:	B<-xvaluesregex>
 
-View the x values which will match with regex. It allows you to display tick on x axis and values 
-that you want. You can combine it with -xlabelskip to perform what you want to display if you have many dataset.
+View the x values which will match with regex. It allows you to display tick on x-axis and values 
+that you want. You can combine it with -xlabelskip to display many dataset.
 
- 
  ...
  ['leg1', 'leg2', 'data1', 'data2', 'symb1', 'symb2']
  ...
- 
+
  -xvaluesregex => qr/leg/i,
 
 On the graph, just leg1 and leg2 will be display.
@@ -1303,8 +1273,8 @@ Default : B<qr/.+/>
 
 =item Switch:	B<-ylabel>
 
-The labels to be printed next to y axis.
- 
+The label to be printed next to y-axis.
+
  -ylabel => 'Y label',
 
 Default : B<undef>
@@ -1316,7 +1286,7 @@ Default : B<undef>
 =item Switch:	B<-ylabelcolor>
 
 Set the color of y label. See also textcolor option. 
- 
+
  -ylabelcolor => 'red',
 
 Default : B<black>
@@ -1328,7 +1298,7 @@ Default : B<black>
 =item Switch:	B<-ylabelfont>
 
 Set the font for the y label text. See also textfont option. 
- 
+
  -ylabelfont => 'Times 15 {normal}',
 
 Default : B<{Times} 10 {bold}>
@@ -1340,7 +1310,7 @@ Default : B<{Times} 10 {bold}>
 =item Switch:	B<-ylabelwidth>
 
 Width of space for y label.
- 
+
  -ylabelwidth => 30,
 
 Default : B<5>
@@ -1352,7 +1322,7 @@ Default : B<5>
 =item Switch:	B<-yvaluecolor>
 
 Set the color of y values. See also valuecolor option.
- 
+
  -yvaluecolor => 'red',
 
 Default : B<black>
@@ -1363,106 +1333,205 @@ Default : B<black>
 
 =item Switch:	B<-yvalueview>
 
-View values on y axis.
+View values on y-axis.
  
  -yvalueview => 0, # 0 or 1
 
 Default : B<1>
 
+=item Name:	B<Yminvalue>
+
+=item Class:	B<YMinValue>
+
+=item Switch:	B<-yminvalue>
+
+Minimum value displayed on the y-axis. See also -interval option.
+ 
+ -yminvalue => 10.12,
+
+Default : B<0>
+
+=item Name:	B<Ymaxvalue>
+
+=item Class:	B<YMaxValue>
+
+=item Switch:	B<-ymaxvalue>
+
+Maximum value displayed on the y-axis. See also -interval option.
+ 
+ -ymaxvalue => 5,
+
+Default : B<Computed from data sets>
+
+=item Name:	B<interval>
+
+=item Class:	B<Interval>
+
+=item Switch:	B<-interval>
+
+If set to a true value, -yminvalue and -ymaxvalue will be fixed to minimum and maximum values of data sets. 
+It overwrites -yminvalue and -ymaxvalue options.
+ 
+ -interval => 1, # 0 or 1
+
+Default : B<0>
+
 =item Name:	B<Labelscolor>
 
-=item Class:	B<LabelsColor>
+=item Class: B<LabelsColor>
 
 =item Switch:	B<-labelscolor>
 
 Combine xlabelcolor and ylabelcolor options. See also textcolor option.
- 
+
  -labelscolor => 'red',
 
 Default : B<undef>
 
 =item Name:	B<Valuescolor>
 
-=item Class:	B<ValuesColor>
+=item Class: B<ValuesColor>
 
 =item Switch:	B<-valuescolor>
 
-Set the color of x, y values in axis. It combines xvaluecolor and yvaluecolor options.
- 
+Set the color of x, y values in axes. It combines xvaluecolor 
+and yvaluecolor options.
+
  -valuescolor => 'red',
 
 Default : B<undef>
 
 =item Name:	B<Textcolor>
 
-=item Class:	B<TextColor>
+=item Class: B<TextColor>
 
 =item Switch:	B<-textcolor>
 
-Set the color of x, y labels and title text. It combines titlecolor, xlabelcolor and ylabelcolor options.
- 
+Set the color of x, y labels and title text. 
+It combines titlecolor, xlabelcolor and ylabelcolor options.
+
  -textcolor => 'red',
 
 Default : B<undef>
 
 =item Name:	B<Textfont>
 
-=item Class:	B<TextFont>
+=item Class: B<TextFont>
 
 =item Switch:	B<-textfont>
 
-Set the font of x, y labels and title text. It combines titlefont, xlabelfont and ylabelfont options.
- 
+Set the font of x, y labels and title text. It combines titlefont, 
+xlabelfont and ylabelfont options.
+
  -textfont => 'Times 15 {normal}',
 
 Default : B<undef>
 
 =item Name:	B<Longticks>
 
-=item Class:	B<LongTicks>
+=item Class: B<LongTicks>
 
 =item Switch:	B<-longticks>
 
-If long_ticks is a true value, ticks will be drawn the same length as the axes.
- 
+If longticks is a true value, x and y ticks will be drawn with the same length as the axes. See also -xlongticks and -ylongticks options. 
+
  -longticks => 1, #  0 or 1
 
 Default : B<0>
 
+=item Name:	B<Longtickscolor>
+
+=item Class: B<LongTicksColor>
+
+=item Switch:	B<-longtickscolor>
+
+Set the color of x and y ticks that will be drawn with the same length as the axes. See also -xlongtickscolor and -ylongtickscolor options.
+
+  -longtickscolor => 'red',
+
+Default : B<undef>
+
+=item Name:	B<XLongticks>
+
+=item Class: B<XLongTicks>
+
+=item Switch:	B<-xlongticks>
+
+If xlongticks is a true value, x ticks will be drawn with the same length as the x-axis. See also -longticks.
+
+ -xlongticks => 1, #  0 or 1
+
+Default : B<0>
+
+=item Name:	B<YLongticks>
+
+=item Class: B<YLongTicks>
+
+=item Switch:	B<-ylongticks>
+
+If ylongticks is a true value, y ticks will be drawn with the same length as the axes. See also -longticks.
+
+ -ylongticks => 1, #  0 or 1
+
+Default : B<0>
+
+=item Name:	B<XLongtickscolor>
+
+=item Class: B<XLongTicksColor>
+
+=item Switch:	B<-xlongtickscolor>
+
+Set the color of xlongticks. See also -xlongtickscolor.
+
+  -xlongtickscolor => 'red',
+
+Default : B<#B3B3B3>
+
+=item Name:	B<YLongtickscolor>
+
+=item Class: B<YLongTicksColor>
+
+=item Switch:	B<-ylongtickscolor>
+
+Set the color of ylongticks. See also -ylongtickscolor.
+
+  -ylongtickscolor => 'red',
+
+Default : B<#B3B3B3>
 
 =item Name:	B<Boxaxis>
 
-=item Class:	B<BoxAxis>
+=item Class: B<BoxAxis>
 
 =item Switch:	B<-boxaxis>
 
 Draw the axes as a box.
- 
+
  -boxaxis => 0, #  0 or 1
 
 Default : B<1>
 
 =item Name:	B<Noaxis>
 
-=item Class:	B<NoAxis>
+=item Class: B<NoAxis>
 
 =item Switch:	B<-noaxis>
 
-Hide the axis with ticks and values ticks.
- 
+Hide the axes with ticks and values ticks.
+
  -noaxis => 1, # 0 or 1
 
 Default : B<0>
 
 =item Name:	B<Zeroaxis>
 
-=item Class:	B<ZeroAxis>
+=item Class: B<ZeroAxis>
 
 =item Switch:	B<-zeroaxis>
 
-If set to a true value, the axis for y values will only be drawn. 
+If set to a true value, the axes for y values will only be drawn. 
 This might be useful in case your graph contains negative values, 
-but you want it to be clear where the zero value is. 
+but you want it to be clear where the zero value is
 (see also zeroaxisonly and boxaxis).
 
  -zeroaxis => 1, # 0 or 1
@@ -1475,15 +1544,27 @@ Default : B<0>
 
 =item Switch:	B<-zeroaxisonly>
 
-If set to a true value, the zero x axis will be drawn and no axis 
+If set to a true value, the zero x-axis will be drawn and no axes 
 at the bottom of the graph will be drawn. 
-The labels for X values will be placed on the zero x axis.
+The labels for X values will be placed on the zero x-axis.
 This works if there is at least one negative value in dataset.
 
  -zeroaxisonly => 1, # 0 or 1
 
 Default : B<0>
 
+=item Name:	B<Axiscolor>
+
+=item Class: B<AxisColor>
+
+=item Switch:	B<-axiscolor>
+
+Color of the axes.
+
+ -axiscolor => 'red',
+
+Default : B<black>
+
 =item Name:	B<Xtickheight>
 
 =item Class:	B<XTickHeight>
@@ -1503,26 +1584,26 @@ Default : B<5>
 =item Switch:	B<-xtickview>
 
 View x ticks of graph.
- 
+
  -xtickview => 0, # 0 or 1
 
 Default : B<1>
 
 =item Name:	B<Yticknumber>
 
-=item Class:	B<YTickNumber>
+=item Class: B<YTickNumber>
 
 =item Switch:	B<-yticknumber>
 
-Number of ticks to print for the Y axis.
- 
+Number of ticks to print for the y-axis.
+
  -yticknumber => 10,
 
 Default : B<4>
 
 =item Name:	B<Ytickwidth>
 
-=item Class:	B<YtickWidth>
+=item Class: B<YtickWidth>
 
 =item Switch:	B<-ytickwidth>
 
@@ -1534,48 +1615,49 @@ Default : B<5>
 
 =item Name:	B<Ytickview>
 
-=item Class:	B<YTickView>
+=item Class: B<YTickView>
 
 =item Switch:	B<-ytickview>
 
 View y ticks of graph.
- 
+
  -ytickview => 0, # 0 or 1
 
 Default : B<1>
 
 =item Name:	B<Alltickview>
 
-=item Class:	B<AllTickView>
+=item Class: B<AllTickView>
 
 =item Switch:	B<-alltickview>
 
 View all ticks of graph. Combines xtickview and ytickview options.
- 
+
  -alltickview => 0, # 0 or 1
 
 Default : B<undef>
 
 =item Name:	B<Linewidth>
 
-=item Class:	B<LineWidth>
+=item Class: B<LineWidth>
 
 =item Switch:	B<-linewidth>
 
 Set width of all lines graph of dataset.
- 
+
  -linewidth => 10,
 
 Default : B<1>
 
 =item Name:	B<Colordata>
 
-=item Class:	B<ColorData>
+=item Class: B<ColorData>
 
 =item Switch:	B<-colordata>
 
-This controls the colors of the lines. This should be a reference to an array of color names.
- 
+This controls the colors of the lines. This should be a reference 
+to an array of color names.
+
  -colordata => [ qw(green pink blue cyan) ],
 
 Default : 
@@ -1589,6 +1671,18 @@ Default :
 The default array contains 24 colors. If you have more than 24 samples, the next line 
 will have the color of the first array case (red).
 
+=item Name:	B<verbose>
+
+=item Class:	B<Verbose>
+
+=item Switch:	B<-verbose>
+
+Warning will be print if necessary.
+ 
+ -verbose => 0,
+
+Default : B<1>
+
 =back
 
 =head1 WIDGET METHODS
@@ -1855,6 +1949,16 @@ Default : B<{Times} 8 {bold}>
 
 =item *
 
+-legendcolor => I<color>
+
+Color of legend text.
+
+ -legendcolor => 'white',
+
+Default : B<'black'>
+
+=item *
+
 -legendfont => I<string>
 
 Set the font to legend text.
